@@ -32,11 +32,9 @@ import java.util.Optional;
 import java.util.Set;
 import java.util.UUID;
 import java.util.concurrent.ConcurrentHashMap;
-import java.util.function.Function;
-import java.util.stream.Collectors;
+import java.util.function.UnaryOperator;
 import java.util.stream.Stream;
 
-import org.apache.openmeetings.core.remote.KurentoHandler;
 import org.apache.openmeetings.db.dao.log.ConferenceLogDao;
 import org.apache.openmeetings.db.entity.basic.Client;
 import org.apache.openmeetings.db.entity.log.ConferenceLog;
@@ -44,6 +42,7 @@ import org.apache.openmeetings.db.entity.room.Room;
 import org.apache.openmeetings.db.manager.IClientManager;
 import org.apache.openmeetings.db.util.ws.RoomMessage;
 import org.apache.openmeetings.db.util.ws.TextRoomMessage;
+import org.apache.openmeetings.mediaserver.KurentoHandler;
 import org.apache.openmeetings.web.pages.auth.SignInPage;
 import org.apache.wicket.request.mapper.parameter.PageParameters;
 import org.apache.wicket.util.string.StringValue;
@@ -322,7 +321,7 @@ public class ClientManager implements IClientManager {
 	private List<Client> getByKeys(Long userId, String sessionId) {
 		return map().values().stream()
 				.filter(c -> c.sameUserId(userId) && c.getSessionId().equals(sessionId))
-				.collect(Collectors.toList());
+				.toList();
 	}
 
 	public void invalidate(Long userId, String sessionId) {
@@ -333,7 +332,7 @@ public class ClientManager implements IClientManager {
 		}
 	}
 
-	private String getServerUrl(Map.Entry<String, ServerInfo> e, Room r, Function<String, String> generator) {
+	private String getServerUrl(Map.Entry<String, ServerInfo> e, Room r, UnaryOperator<String> generator) {
 		final String curServerId = app.getServerId();
 		String serverId = e.getKey();
 		if (!curServerId.equals(serverId)) {
@@ -343,12 +342,12 @@ public class ClientManager implements IClientManager {
 		return null;
 	}
 
-	public String getServerUrl(Room r, Function<String, String> inGenerator) {
+	public String getServerUrl(Room r, UnaryOperator<String> inGenerator) {
 		if (onlineServers.size() == 1) {
 			log.debug("Cluster:: The only server found");
 			return null;
 		}
-		Function<String, String> generator = inGenerator == null ? baseUrl -> {
+		UnaryOperator<String> generator = inGenerator == null ? baseUrl -> {
 			String uuid = UUID.randomUUID().toString();
 			tokens().put(uuid, new InstantToken(getUserId(), r.getId()));
 			return Application.urlForPage(SignInPage.class, new PageParameters().add(TOKEN_PARAM, uuid), baseUrl);
