@@ -26,7 +26,6 @@ import java.util.List;
 import org.apache.http.auth.UsernamePasswordCredentials;
 import org.apache.http.client.HttpClient;
 import org.apache.http.client.protocol.HttpClientContext;
-import org.apache.openmeetings.db.dao.calendar.AppointmentDao;
 import org.apache.openmeetings.db.dao.user.UserDao;
 import org.apache.openmeetings.db.entity.calendar.Appointment;
 import org.apache.openmeetings.db.entity.calendar.OmCalendar;
@@ -77,8 +76,6 @@ public class CalendarDialog extends Modal<OmCalendar> {
 	@SpringBean
 	private UserDao userDao;
 	@SpringBean
-	private AppointmentDao apptDao;
-	@SpringBean
 	private AppointmentManager apptManager;
 
 	public enum DIALOG_TYPE {
@@ -117,7 +114,7 @@ public class CalendarDialog extends Modal<OmCalendar> {
 						HttpClient client = calendarPanel.getHttpClient();
 						HttpClientContext context = calendarPanel.getHttpClientContext();
 
-						if (form.gcal.getModelObject()) {
+						if (Boolean.TRUE.equals(form.gcal.getModelObject())) {
 							c.setSyncType(OmCalendar.SyncType.GOOGLE_CALENDAR);
 							c.setToken(form.username.getModelObject());
 							if (c.getId() == null) {
@@ -195,9 +192,7 @@ public class CalendarDialog extends Modal<OmCalendar> {
 					case DELETE_APPOINTMENT:
 						deleteAppointment(a);
 						break;
-					case SYNC_CALENDAR:
-						break;
-					case UPDATE_CALENDAR:
+					case SYNC_CALENDAR, UPDATE_CALENDAR:
 						break;
 					default:
 						break;
@@ -232,9 +227,7 @@ public class CalendarDialog extends Modal<OmCalendar> {
 					calendarPanel.refresh(handler);
 				}
 				break;
-			case DELETE_APPOINTMENT:
-				break;
-			case UPDATE_APPOINTMENT:
+			case DELETE_APPOINTMENT, UPDATE_APPOINTMENT:
 				break;
 			default:
 				break;
@@ -351,9 +344,7 @@ public class CalendarDialog extends Modal<OmCalendar> {
 
 	public void setButtons(IPartialPageRequestHandler target) {
 		switch (type) {
-			case UPDATE_APPOINTMENT:
-			case DELETE_APPOINTMENT:
-			case SYNC_CALENDAR:
+			case UPDATE_APPOINTMENT, DELETE_APPOINTMENT, SYNC_CALENDAR:
 				target.add(delete.setVisible(false), save.setVisible(true));
 				break;
 			case UPDATE_CALENDAR:
@@ -364,6 +355,9 @@ public class CalendarDialog extends Modal<OmCalendar> {
 					target.add(delete.setVisible(isOwner(c)));
 				}
 				target.add(save.setVisible(isOwner(c)));
+				break;
+			default:
+				break;
 		}
 	}
 
@@ -392,7 +386,7 @@ public class CalendarDialog extends Modal<OmCalendar> {
 			@Override
 			public void validate(IValidatable<String> validatable) {
 				//Only Validate when It's not a Google Calendar i.e a URL
-				if (!gcal.getModelObject()) {
+				if (Boolean.FALSE.equals(gcal.getModelObject())) {
 					super.validate(validatable);
 				}
 			}
@@ -463,9 +457,7 @@ public class CalendarDialog extends Modal<OmCalendar> {
 					}
 					setGCalVisibility(calendar);
 					break;
-				case SYNC_CALENDAR:
-				case UPDATE_APPOINTMENT:
-				case DELETE_APPOINTMENT:
+				case SYNC_CALENDAR, UPDATE_APPOINTMENT, DELETE_APPOINTMENT:
 					title.setEnabled(false);
 					url.setEnabled(false);
 					username.setEnabled(true);
@@ -473,6 +465,8 @@ public class CalendarDialog extends Modal<OmCalendar> {
 					gcal.setEnabled(false);
 					setGCalVisibility(calendar);
 					break;
+				default:
+					break;
 			}
 		}
 
@@ -509,7 +503,7 @@ public class CalendarDialog extends Modal<OmCalendar> {
 
 			//Add new AttributeModifier to change the type of URLTextField, to text for
 			//Google Calendar and to URL for a normal CalDAV calendar
-			url.add(AttributeModifier.replace("type", gcal.getModelObject() ? "text" : "url"));
+			url.add(AttributeModifier.replace("type", Boolean.TRUE.equals(gcal.getModelObject()) ? "text" : "url"));
 		}
 
 
@@ -520,35 +514,36 @@ public class CalendarDialog extends Modal<OmCalendar> {
 		 */
 		@Override
 		protected void onValidate() {
-			if (!hasError()) {
-				switch (type) {
-					case UPDATE_CALENDAR:
-						if (getModelObject().getId() != null || gcal.getModelObject()) {
+			if (hasError()) {
+				return;
+			}
+			switch (type) {
+				case UPDATE_CALENDAR:
+					if (getModelObject().getId() != null || gcal.getModelObject()) {
+						return;
+					}
+				case UPDATE_APPOINTMENT, DELETE_APPOINTMENT, SYNC_CALENDAR:
+					try {
+						OmCalendar calendar = getModelObject();
+						if (url.isEnabled()) {
+							calendar.setHref(url.getInput());
+						}
+						HttpClient client = calendarPanel.getHttpClient();
+						HttpClientContext context = calendarPanel.getHttpClientContext();
+
+						apptManager.provideCredentials(context, calendar,
+								new UsernamePasswordCredentials(username.getInput(), pass.getInput()));
+						if (apptManager.testConnection(client, context, calendar)) {
 							return;
 						}
-					case UPDATE_APPOINTMENT:
-					case DELETE_APPOINTMENT:
-					case SYNC_CALENDAR:
-						try {
-							OmCalendar calendar = getModelObject();
-							if (url.isEnabled()) {
-								calendar.setHref(url.getInput());
-							}
-							HttpClient client = calendarPanel.getHttpClient();
-							HttpClientContext context = calendarPanel.getHttpClientContext();
+					} catch (Exception e) {
+						log.error("Error executing the TestConnection", e);
+					}
 
-							apptManager.provideCredentials(context, calendar,
-									new UsernamePasswordCredentials(username.getInput(), pass.getInput()));
-							if (apptManager.testConnection(client, context, calendar)) {
-								return;
-							}
-						} catch (Exception e) {
-							log.error("Error executing the TestConnection", e);
-						}
-
-						error(getString("calendar.error"));
-						break;
-				}
+					error(getString("calendar.error"));
+					break;
+				default:
+					break;
 			}
 		}
 	}
